/*****************************************************************************
*   $Id: read.h,v 1.1 1998/10/18 15:34:57 darren Exp $
*
*   Copyright (c) 1998, Darren Hiebert
*
*   This source code is released for free distribution under the terms of the
*   GNU General Public License.
*
*   External interface to read.c
*****************************************************************************/
#ifndef _READ_H
#define _READ_H

#ifdef FILE_WRITE
# define CONST_FILE
#else
# define CONST_FILE const
#endif

/*============================================================================
=   Include files
============================================================================*/
#include "general.h"
#include <stdio.h>
#include "vstring.h"

/*============================================================================
=   Data declarations
============================================================================*/

/*  Maintains the state of the current source file.
 */
typedef struct _inputFile {
    char	*name;		/* name of the input file */
    char	*path;		/* the path of the input file (if any) */
    FILE	*fp;		/* stream used for reading the file */
    unsigned long lineNumber;	/* line number in the input file */
    long	seek;		/* fseek() offset to start of current line */
    int		ungetch;	/* a single character that was ungotten */
    boolean	newLine;	/* will the next character begin a new line? */
    boolean	isHeader;	/* is input file a header file? */
    langType	language;	/* language of input file */

    /*  Contains data pertaining to the original source file in which the tag
     *  was defined. This may be different from the input file when #line
     *  directives are processed (i.e. the input file is preprocessor output).
     */
    struct {
	char	*name;			/* name to report for source file */
	unsigned long lineNumber;	/* line number in the source file */
	boolean	 isHeader;		/* is source file a header file? */
	langType language;		/* language of source file */
    } source;
} inputFile;

/*============================================================================
=   Global variables
============================================================================*/
extern CONST_FILE inputFile File;

/*============================================================================
=   Function prototypes
============================================================================*/
extern char *readLine __ARGS((vString *const vLine, FILE *const fp));
extern void setSourceFileParameters __ARGS((const char *const fileName, const langType language, const boolean isHeader));
extern void setSourceFileLine __ARGS((const long unsigned int lineNumber));
extern boolean fileOpen __ARGS((const char *const fileName, const langType language, const boolean isHeader));
extern void fileClose __ARGS((void));
extern int fileGetc __ARGS((void));
extern void fileUngetc __ARGS((int c));
extern char *readSourceLine __ARGS((vString *const vLine, const long int location));

#endif	/* _READ_H */

/* vi:set tabstop=8 shiftwidth=4: */
